@@ -10,6 +10,7 @@ class DatasetPreprocess:
     training_length: int
     validation_length: int
     test_length: Optional[int] = None
+    unlabeled_length: Optional[int] = None
 
 
 @dataclass
@@ -33,7 +34,7 @@ class DatasetOutputInstance(DatasetBaseSectionInstance):
 
 
 @dataclass
-class DecoderInstance:
+class VisualizerInstance:
     name: str
     type: LeapDataType
     arg_names: List[str]
@@ -53,7 +54,7 @@ class DatasetSetup:
     inputs: List[DatasetInputInstance]
     metadata: List[DatasetMetadataInstance]
     outputs: List[DatasetOutputInstance]
-    decoders: List[DecoderInstance]
+    visualizers: List[VisualizerInstance]
     prediction_types: List[PredictionTypeInstance]
     custom_loss_names: List[str]
 
@@ -70,5 +71,5 @@ class DatasetTestResultPayload:
 class DatasetIntegParseResult:
     payloads: List[DatasetTestResultPayload]
     is_valid: bool
-    setup: Optional[DatasetSetup]
-    general_error: Optional[str]
+    setup: Optional[DatasetSetup] = None
+    general_error: Optional[str] = None
